@@ -1,5 +1,5 @@
 package DBIx::Class::AuditLog;
-$DBIx::Class::AuditLog::VERSION = '0.6.3';
+$DBIx::Class::AuditLog::VERSION = '0.6.4';
 use base qw/DBIx::Class/;
 
 use strict;
@@ -154,9 +154,14 @@ sub _store_changes {
 sub _force_audit {
     my ( $self, $column ) = @_;
 
-    my $info = $self->column_info($column);
-    return defined $info->{force_audit_log_column};
+    ## make sure that this is an actual column, and is not
+    ## a correlated column
+    return unless $self->has_column($column);
 
+    my $info = $self->column_info($column);
+
+    return defined $info->{force_audit_log_column}
+        && $info->{force_audit_log_column};
 }
 
 sub _do_audit {
@@ -218,7 +223,7 @@ DBIx::Class::AuditLog - Simple activity audit logging for DBIx::Class
 
 =head1 VERSION
 
-version 0.6.3
+version 0.6.4
 
 =head1 NAME
 
